@@ -3,8 +3,8 @@
 	
 	@author	Daniele Maio (b0unc3) 
 	@date	18/07/2010
-	@update	12/08/2010
-	@ver	0.6
+	@update	17/10/2010
+	@ver	0.9
 	
 */
 #include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
@@ -120,21 +120,11 @@ save_info(GtkWidget *wid, gpointer user_data)
 		lst = NULL;
 	}
 	
-	//	GtkWidget 	*shutter,*pkey;
 	if ( hildon_check_button_get_active ( HILDON_CHECK_BUTTON(shutter) ) ) 
 		gconf_client_set_bool (client, g_strdup_printf("%sshutter",APP_GCONF_KEY), TRUE, NULL);
-//		gconf_client_set_string(client, g_strdup_printf("%sshutter",APP_GCONF_KEY), "active", NULL);
 	else
 		gconf_client_set_bool (client, g_strdup_printf("%sshutter",APP_GCONF_KEY), FALSE, NULL);
 		
-		
-	if ( hildon_check_button_get_active ( HILDON_CHECK_BUTTON(pkey) ) )
-		gconf_client_set_bool (client, g_strdup_printf("%spower_key",APP_GCONF_KEY), TRUE, NULL);
-//		gconf_client_set_string(client, g_strdup_printf("%spower_key",APP_GCONF_KEY), "active", NULL);
-	else
-		gconf_client_set_bool (client, g_strdup_printf("%spower_key",APP_GCONF_KEY), FALSE, NULL);
-//		gconf_client_set_string(client, g_strdup_printf("%spower_key",APP_GCONF_KEY), "inactive", NULL);
-
 	
 	gtk_widget_set_sensitive ( GTK_WIDGET(confirm), FALSE );
 	
@@ -180,11 +170,6 @@ parse_settings(GConfClient* client)
 			hildon_check_button_set_active ( HILDON_CHECK_BUTTON(shutter), TRUE );
 		else hildon_check_button_set_active ( HILDON_CHECK_BUTTON(shutter), FALSE );
 		
-	if (gconf_entry_get_value(g_strdup_printf("%spower_key",APP_GCONF_KEY)) != NULL)	
-		if ( gconf_client_get_bool (GCONF_CLIENT(client), g_strdup_printf("%spower_key",APP_GCONF_KEY), &err) )
-			hildon_check_button_set_active ( HILDON_CHECK_BUTTON(pkey), TRUE );
-		else hildon_check_button_set_active ( HILDON_CHECK_BUTTON(pkey), FALSE );
-	
 }
 
 gboolean
@@ -328,15 +313,6 @@ add_apps( HildonTouchSelector *btn, gpointer p)
          
 	hildon_touch_selector_set_live_search ( HILDON_TOUCH_SELECTOR(btn), TRUE );
         
-       /* 
- 	GtkTreeModel *m;
- 	GtkTreeSortable *sortable;
- 	       
-        m = hildon_touch_selector_get_model (HILDON_TOUCH_SELECTOR(btn),0);
-        sortable = GTK_TREE_SORTABLE(m);
-	gtk_tree_sortable_set_sort_func(sortable, NULL, sort_iter_compare_func, NULL,NULL );
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(sortable), 0, GTK_SORT_ASCENDING);
-	hildon_touch_selector_set_model ( HILDON_TOUCH_SELECTOR(btn), 0, GTK_TREE_MODEL(sortable) );*/
 	GtkWidget *tmp;
 	GtkWidget *b;
 	
@@ -416,16 +392,15 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	hildon_button_set_image ( HILDON_BUTTON(confirm), gtk_image_new_from_stock(GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON) );
 	
 	shutter = hildon_check_button_new ( HILDON_SIZE_FINGER_HEIGHT );
-	pkey = hildon_check_button_new ( HILDON_SIZE_FINGER_HEIGHT );
+
 	gtk_button_set_label (GTK_BUTTON (shutter), "Enable launch on shutter open");
-	gtk_button_set_label (GTK_BUTTON (pkey), "Enable launch on power key press");
+
 
     	g_signal_connect (shutter, "toggled", G_CALLBACK (button_toggled), NULL);
-	g_signal_connect (pkey, "toggled", G_CALLBACK (button_toggled), NULL);
+
 
 	
 	gtk_box_pack_start ( GTK_BOX(action_box), shutter, FALSE,FALSE,0 );
-	gtk_box_pack_start ( GTK_BOX(action_box), pkey, FALSE,FALSE,0 );
 	gtk_box_pack_start ( GTK_BOX(action_box), confirm, FALSE,FALSE,0 );
 
 	gtk_box_pack_start ( GTK_BOX(main_box), conf_box, TRUE, TRUE, 1 );
