@@ -15,18 +15,20 @@ const char *hal_key = NULL;
 DBusError dbus_err;
 static LibHalContext *halctx;
 static gchar *cam_shutter_udi = "/org/freedesktop/Hal/devices/platform_cam_shutter";
-static gchar *powerkey_udi = "/org/freedesktop/Hal/devices/computer_logicaldev_input";
 
 
 
 static gboolean
-is_running()
+is_running(int w)
 {
     FILE *process_listing;
     char line[130];
     int counter = 0;
 
-    char *pattern = "quick-launch-dialog";
+    char *pattern;
+    if ( w == 0 )
+	    pattern = "quick-launch-dialog";
+    else pattern = "camera-ui";
 
     int regex_result;
     regex_t re;
@@ -115,24 +117,10 @@ static void set_hal_uid (GConfClient *client)
 	
 	//remove ancient property_watch
 	libhal_device_remove_property_watch (halctx, cam_shutter_udi, &dbus_err);
-	libhal_device_remove_property_watch (halctx, powerkey_udi, &dbus_err);
 	
-	previous_state = FALSE;
 	if (gconf_entry_get_value (g_strdup_printf("%sshutter",APP_GCONF_KEY)) != NULL) {
 		if ( gconf_client_get_bool (GCONF_CLIENT(client),g_strdup_printf("%sshutter",APP_GCONF_KEY),  NULL) )
-		{
 			libhal_device_add_property_watch(halctx, cam_shutter_udi, &dbus_err);
-			system("dsmetool -k /usr/bin/camera-ui");
-		} else system("dsmetool -r /usr/bin/camera-ui");
-/*		else 
-			libhal_device_remove_property_watch (halctx, cam_shutter_udi, &dbus_err);*/
-	} 
-	
-	if (gconf_entry_get_value (g_strdup_printf("%spower_key",APP_GCONF_KEY)) != NULL) {
-		if ( gconf_client_get_bool (GCONF_CLIENT(client),g_strdup_printf("%spower_key",APP_GCONF_KEY),  NULL) )
-			libhal_device_add_property_watch(halctx, powerkey_udi, &dbus_err);
-/*		else
-			libhal_device_remove_property_watch (halctx, powerkey_udi, &dbus_err);*/
 	} 
 	
 	printf("hal_key changed to = %s\n",hal_key);
@@ -152,17 +140,14 @@ static void cond ( LibHalContext *ctx,
 	GError *error;
 	
 	
-	if ( !is_locked() && !is_running() ) { //execute only if the screen is unlocked
-		g_print("screen active\n");
-		g_print("not locked,not running \n");
-//		if ( g_strcmp0(interface_name,cam_shutter_udi) == 0 ) 
-		
-		if ( g_strcmp0(interface_name,cam_shutter_udi) == 0 && !previous_state )
-			previous_state = TRUE;
-		else if ( g_strcmp0(interface_name,cam_shutter_udi) == 0 && previous_state ) {
-			previous_state = FALSE;
-			return FALSE;
-		}
+	
+	
+	system("killall -9 camera-ui");
+	if ( !is_locked() && !is_running(0) ) { //execute only if the screen is unlocked
+	
+		if ( !libhal_device_get_property_bool ( ctx, cam_shutter_udi, "button.state.value", NULL ) ) { //shutter is open
+			g_print("screen active\n");
+			g_print("not locked,not running, shutter open \n");
 		
 			if (g_shell_parse_argv("/usr/bin/quick-launch-dialog",&argc,&argv,NULL)) {
 				if ( g_spawn_async(NULL,argv,NULL,(GSpawnFlags)G_SPAWN_SEARCH_PATH,NULL,NULL,&pid,&error) ) {
@@ -171,13 +156,14 @@ static void cond ( LibHalContext *ctx,
 					return FALSE;
 				} else return FALSE;
 			} else return FALSE;
-				
+			
 			if (error)
 			{
 				hildon_banner_show_information(NULL, NULL, "Execution failed");
 				g_error_free(error);
 				return FALSE;
 			}
+		} else return FALSE;
 			
 	} else g_print("screen locked!\n");
 }
@@ -230,8 +216,6 @@ int main ( int argc, char *argv[] )
                           NULL,
                           NULL, NULL);
                           
-
-	previous_state = FALSE;  
 	set_hal_uid (client);
 
 	g_main_loop_run( loop );
