@@ -1,6 +1,8 @@
 #include <hildon/hildon.h>
 #include <gconf/gconf-client.h>
 #include <locale.h>
+#include <libosso.h>
+
 
 #include "quick-launch.h"
 
@@ -128,7 +130,19 @@ int main ( int argc, char *argv[] )
 	GtkTreeModel *completion_model;
 	gint response;
 	
+	osso_context_t  *osso_context;
+
+        /* Initialize maemo application */
+        osso_context = osso_initialize("quick_launch", "0.9.0", TRUE, NULL);
+
+        /* Check that initialization was ok */
+        if (osso_context == NULL)
+        {
+                    return OSSO_ERROR;
+        }
+
 	hildon_gtk_init (&argc, &argv);
+	printf("init\n");
 	d = HILDON_DIALOG (hildon_dialog_new ());
 	gtk_window_set_title (GTK_WINDOW (d), "QuickLaunch");
 	GtkWidget *table;
@@ -140,17 +154,18 @@ int main ( int argc, char *argv[] )
 	hildon_entry_set_text ( HILDON_ENTRY(sentry), "Type an app name" );
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (GTK_ENTRY (sentry), completion);
-	g_object_unref (completion);
+//	g_object_unref (completion);
     
 	/* Create a tree model and use it as the completion model */
 	completion_model = create_completion_model ();
 	gtk_entry_completion_set_model (completion, completion_model);
-	g_object_unref (completion_model);
+//	g_object_unref (completion_model);
     
 	/* Use model column 0 as the text column */
 	gtk_entry_completion_set_text_column (completion, 0);
 	
 	int i;
+	printf("before four\n");
    	for(i=0;i<4;i++) {
 	   	btns[i] = hildon_button_new(HILDON_SIZE_FULLSCREEN_WIDTH, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 	   	gtk_widget_set_size_request ( GTK_WIDGET(btns[i]), 64,64 );
@@ -158,6 +173,7 @@ int main ( int argc, char *argv[] )
 	//	gtk_box_pack_start(GTK_BOX(bbox), btns[i], FALSE, FALSE, 1);
 		g_signal_connect ( G_OBJECT(btns[i]), "clicked", G_CALLBACK(load_app), (gpointer) i);
 	}
+	printf("after for\n");
 	client = gconf_client_get_default();
 	
 	gconf_client_add_dir(client,
