@@ -3,8 +3,8 @@
 	
 	@author	Daniele Maio (b0unc3) 
 	@date	16/02/2010
-	@update 27/07/2010
-	@ver	0.6
+	@update 17/10/2010
+	@ver	0.9
 	
 */
 #ifndef __QUICK_LAUNCH_STATUS_MENU_ITEM_H__
@@ -62,16 +62,14 @@ GtkWidget 		*btns[4];
 static gchar 		*group_name[4] = { "first", "second", "third", "fourth" };
 static GtkWidget 	*confirm;
 static GtkWidget 	*window;
-static GtkWidget 	*shutter,*pkey;
+static GtkWidget 	*shutter;
 static GConfClient	*client;
 HildonDialog 		*d;
-gboolean 		previous_state; //true=open->close false=close->open
 
 void parse_info (GConfClient* client, gboolean big_icon);
 gboolean load_app(GtkWidget *widget , gpointer data);
 gboolean app_search_button_release(GtkWidget* widget, GdkEventButton *event);
 gboolean app_search_filter_app_list_func(GtkTreeModel* model, GtkTreeIter* iter, gpointer data);
-//gchar * app_search_search_retrive_app_name(GKeyFile* key_file);
 /**/
 
 G_END_DECLS
